pub struct AgentLoop {
pub state: ReactState,
pub turn_count: usize,
pub max_turns: usize,
/* private fields */
}Fields
state: ReactStateturn_count: usizemax_turns: usizeImplementations
Sourceimpl AgentLoop
impl AgentLoop
pub fn new(max_turns: usize) -> Self
pub fn transition(&mut self, action: ReactAction) -> ReactState
pub fn is_idle(&self) -> bool
Sourcepub fn is_looping(&self, tool_name: &str, params: &str) -> bool
pub fn is_looping(&self, tool_name: &str, params: &str) -> bool
Returns true if the same tool+params combination has appeared
LOOP_DETECTION_WINDOW consecutive times.
Sourcepub fn record_tool_error(&mut self, tool: &str, params: &str, error: &str)
pub fn record_tool_error(&mut self, tool: &str, params: &str, error: &str)
Record a tool call failure so subsequent identical calls can be suppressed.
Sourcepub fn should_suppress_duplicate(&self, tool: &str, params: &str) -> bool
pub fn should_suppress_duplicate(&self, tool: &str, params: &str) -> bool
Returns true if the given tool+params matches the most recent failure.
pub fn increment_suppressed(&mut self)
Sourcepub fn should_abort_error_loop(&self) -> bool
pub fn should_abort_error_loop(&self) -> bool
After 2 suppressions the model is stuck — caller should abort the batch.
pub fn last_error(&self) -> Option<&str>
Sourcepub fn clear_error_state(&mut self)
pub fn clear_error_state(&mut self)
Clear error dedup state after a successful tool call.