pub struct ScriptRunner { /* private fields */ }Implementations
Sourceimpl ScriptRunner
impl ScriptRunner
pub fn new(config: SkillsConfig, fs_security: FilesystemSecurityConfig) -> Self
pub async fn execute( &self, script_path: &Path, args: &[&str], ) -> Result<ScriptResult>
Sourcepub fn resolve_script_path(&self, requested: &Path) -> Result<PathBuf>
pub fn resolve_script_path(&self, requested: &Path) -> Result<PathBuf>
Resolve a requested script path under the configured skills root.
This canonicalizes both root and script path and enforces containment.