pub fn compact(
entries: &[ContextEntry],
config: &CompactionConfig,
) -> CompactedContextExpand description
Compact a set of context entries into a minimal-footprint text block.
This is the single entry point for all context compaction. Every memory
section should be converted to ContextEntry structs and passed through
this function before entering the token budget.